==> cdktf-provider-google-13.1.0-sources.jar: com/hashicorp/cdktf/providers/google/cloud_run_v2_service/CloudRunV2ServiceTemplateContainersResources.java <==
package com.hashicorp.cdktf.providers.google.cloud_run_v2_service;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-17T04:17:39.125Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.cloudRunV2Service.CloudRunV2ServiceTemplateContainersResources")
@software.amazon.jsii.Jsii.Proxy(CloudRunV2ServiceTemplateContainersResources.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CloudRunV2ServiceTemplateContainersResources extends software.amazon.jsii.JsiiSerializable {

    /**
     * Determines whether CPU should be throttled or not outside of requests.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/cloud_run_v2_service#cpu_idle CloudRunV2Service#cpu_idle}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getCpuIdle() {
        return null;
    }

    /**
     * Only memory and CPU are supported.
     * <p>
     * Use key 'cpu' for CPU limit and 'memory' for memory limit. Note: The only supported values for CPU are '1', '2', '4', and '8'. Setting 4 CPU requires at least 2Gi of memory. The values of the map is string form of the 'quantity' k8s type: https://github.com/kubernetes/kubernetes/blob/master/staging/src/k8s.io/apimachinery/pkg/api/resource/quantity.go
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/cloud_run_v2_service#limits CloudRunV2Service#limits}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.Map<java.lang.String, java.lang.String> getLimits() {
        return null;
    }

    /**
     * Determines whether CPU should be boosted on startup of a new container instance above the requested CPU threshold, this can help reduce cold-start latency.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/cloud_run_v2_service#startup_cpu_boost CloudRunV2Service#startup_cpu_boost}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getStartupCpuBoost() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CloudRunV2ServiceTemplateContainersResources}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CloudRunV2ServiceTemplateContainersResources}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CloudRunV2ServiceTemplateContainersResources> {
        java.lang.Object cpuIdle;
        java.util.Map<java.lang.String, java.lang.String> limits;
        java.lang.Object startupCpuBoost;

        /**
         * Sets the value of {@link CloudRunV2ServiceTemplateContainersResources#getCpuIdle}
         * @param cpuIdle Determines whether CPU should be throttled or not outside of requests.
         *                Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/cloud_run_v2_service#cpu_idle CloudRunV2Service#cpu_idle}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cpuIdle(java.lang.Boolean cpuIdle) {
            this.cpuIdle = cpuIdle;
            return this;
        }

        /**
         * Sets the value of {@link CloudRunV2ServiceTemplateContainersResources#getCpuIdle}
         * @param cpuIdle Determines whether CPU should be throttled or not outside of requests.
         *                Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/cloud_run_v2_service#cpu_idle CloudRunV2Service#cpu_idle}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cpuIdle(com.hashicorp.cdktf.IResolvable cpuIdle) {
            this.cpuIdle = cpuIdle;
            return this;
        }

        /**
         * Sets the value of {@link CloudRunV2ServiceTemplateContainersResources#getLimits}
         * @param limits Only memory and CPU are supported.
         *               Use key 'cpu' for CPU limit and 'memory' for memory limit. Note: The only supported values for CPU are '1', '2', '4', and '8'. Setting 4 CPU requires at least 2Gi of memory. The values of the map is string form of the 'quantity' k8s type: https://github.com/kubernetes/kubernetes/blob/master/staging/src/k8s.io/apimachinery/pkg/api/resource/quantity.go
         *               
         *               Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/cloud_run_v2_service#limits CloudRunV2Service#limits}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder limits(java.util.Map<java.lang.String, java.lang.String> limits) {
            this.limits = limits;
            return this;
        }

        /**
         * Sets the value of {@link CloudRunV2ServiceTemplateContainersResources#getStartupCpuBoost}
         * @param startupCpuBoost Determines whether CPU should be boosted on startup of a new container instance above the requested CPU threshold, this can help reduce cold-start latency.
         *                        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/cloud_run_v2_service#startup_cpu_boost CloudRunV2Service#startup_cpu_boost}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder startupCpuBoost(java.lang.Boolean startupCpuBoost) {
            this.startupCpuBoost = startupCpuBoost;
            return this;
        }

        /**
         * Sets the value of {@link CloudRunV2ServiceTemplateContainersResources#getStartupCpuBoost}
         * @param startupCpuBoost Determines whether CPU should be boosted on startup of a new container instance above the requested CPU threshold, this can help reduce cold-start latency.
         *                        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/cloud_run_v2_service#startup_cpu_boost CloudRunV2Service#startup_cpu_boost}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder startupCpuBoost(com.hashicorp.cdktf.IResolvable startupCpuBoost) {
            this.startupCpuBoost = startupCpuBoost;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CloudRunV2ServiceTemplateContainersResources}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CloudRunV2ServiceTemplateContainersResources build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CloudRunV2ServiceTemplateContainersResources}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CloudRunV2ServiceTemplateContainersResources {
        private final java.lang.Object cpuIdle;
        private final java.util.Map<java.lang.String, java.lang.String> limits;
        private final java.lang.Object startupCpuBoost;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.cpuIdle = software.amazon.jsii.Kernel.get(this, "cpuIdle", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.limits = software.amazon.jsii.Kernel.get(this, "limits", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.startupCpuBoost = software.amazon.jsii.Kernel.get(this, "startupCpuBoost", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.cpuIdle = builder.cpuIdle;
            this.limits = builder.limits;
            this.startupCpuBoost = builder.startupCpuBoost;
        }

        @Override
        public final java.lang.Object getCpuIdle() {
            return this.cpuIdle;
        }

        @Override
        public final java.util.Map<java.lang.String, java.lang.String> getLimits() {
            return this.limits;
        }

        @Override
        public final java.lang.Object getStartupCpuBoost() {
            return this.startupCpuBoost;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getCpuIdle() != null) {
                data.set("cpuIdle", om.valueToTree(this.getCpuIdle()));
            }
            if (this.getLimits() != null) {
                data.set("limits", om.valueToTree(this.getLimits()));
            }
            if (this.getStartupCpuBoost() != null) {
                data.set("startupCpuBoost", om.valueToTree(this.getStartupCpuBoost()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-google.cloudRunV2Service.CloudRunV2ServiceTemplateContainersResources"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CloudRunV2ServiceTemplateContainersResources.Jsii$Proxy that = (CloudRunV2ServiceTemplateContainersResources.Jsii$Proxy) o;

            if (this.cpuIdle != null ? !this.cpuIdle.equals(that.cpuIdle) : that.cpuIdle != null) return false;
            if (this.limits != null ? !this.limits.equals(that.limits) : that.limits != null) return false;
            return this.startupCpuBoost != null ? this.startupCpuBoost.equals(that.startupCpuBoost) : that.startupCpuBoost == null;
        }

        @Override
        public final int hashCode() {
            int result = this.cpuIdle != null ? this.cpuIdle.hashCode() : 0;
            result = 31 * result + (this.limits != null ? this.limits.hashCode() : 0);
            result = 31 * result + (this.startupCpuBoost != null ? this.startupCpuBoost.hashCode() : 0);
            return result;
        }
    }
}

==> cdktf-provider-google-13.13.0-sources.jar: com/hashicorp/cdktf/providers/google/cloud_run_v2_service/CloudRunV2ServiceTemplateContainersResources.java <==
package com.hashicorp.cdktf.providers.google.cloud_run_v2_service;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.96.0 (build 921e240)", date = "2024-04-09T03:36:13.024Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.cloudRunV2Service.CloudRunV2ServiceTemplateContainersResources")
@software.amazon.jsii.Jsii.Proxy(CloudRunV2ServiceTemplateContainersResources.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CloudRunV2ServiceTemplateContainersResources extends software.amazon.jsii.JsiiSerializable {

    /**
     * Determines whether CPU is only allocated during requests.
     * <p>
     * True by default if the parent 'resources' field is not set. However, if
     * 'resources' is set, this field must be explicitly set to true to preserve the default behavior.
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/cloud_run_v2_service#cpu_idle CloudRunV2Service#cpu_idle}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getCpuIdle() {
        return null;
    }

    /**
     * Only memory and CPU are supported.
     * <p>
     * Use key 'cpu' for CPU limit and 'memory' for memory limit. Note: The only supported values for CPU are '1', '2', '4', and '8'. Setting 4 CPU requires at least 2Gi of memory. The values of the map is string form of the 'quantity' k8s type: https://github.com/kubernetes/kubernetes/blob/master/staging/src/k8s.io/apimachinery/pkg/api/resource/quantity.go
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/cloud_run_v2_service#limits CloudRunV2Service#limits}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.Map<java.lang.String, java.lang.String> getLimits() {
        return null;
    }

    /**
     * Determines whether CPU should be boosted on startup of a new container instance above the requested CPU threshold, this can help reduce cold-start latency.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/cloud_run_v2_service#startup_cpu_boost CloudRunV2Service#startup_cpu_boost}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getStartupCpuBoost() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CloudRunV2ServiceTemplateContainersResources}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CloudRunV2ServiceTemplateContainersResources}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CloudRunV2ServiceTemplateContainersResources> {
        java.lang.Object cpuIdle;
        java.util.Map<java.lang.String, java.lang.String> limits;
        java.lang.Object startupCpuBoost;

        /**
         * Sets the value of {@link CloudRunV2ServiceTemplateContainersResources#getCpuIdle}
         * @param cpuIdle Determines whether CPU is only allocated during requests.
         *                True by default if the parent 'resources' field is not set. However, if
         *                'resources' is set, this field must be explicitly set to true to preserve the default behavior.
         *                
         *                Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/cloud_run_v2_service#cpu_idle CloudRunV2Service#cpu_idle}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cpuIdle(java.lang.Boolean cpuIdle) {
            this.cpuIdle = cpuIdle;
            return this;
        }

        /**
         * Sets the value of {@link CloudRunV2ServiceTemplateContainersResources#getCpuIdle}
         * @param cpuIdle Determines whether CPU is only allocated during requests.
         *                True by default if the parent 'resources' field is not set. However, if
         *                'resources' is set, this field must be explicitly set to true to preserve the default behavior.
         *                
         *                Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/cloud_run_v2_service#cpu_idle CloudRunV2Service#cpu_idle}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cpuIdle(com.hashicorp.cdktf.IResolvable cpuIdle) {
            this.cpuIdle = cpuIdle;
            return this;
        }

        /**
         * Sets the value of {@link CloudRunV2ServiceTemplateContainersResources#getLimits}
         * @param limits Only memory and CPU are supported.
         *               Use key 'cpu' for CPU limit and 'memory' for memory limit. Note: The only supported values for CPU are '1', '2', '4', and '8'. Setting 4 CPU requires at least 2Gi of memory. The values of the map is string form of the 'quantity' k8s type: https://github.com/kubernetes/kubernetes/blob/master/staging/src/k8s.io/apimachinery/pkg/api/resource/quantity.go
         *               
         *               Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/cloud_run_v2_service#limits CloudRunV2Service#limits}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder limits(java.util.Map<java.lang.String, java.lang.String> limits) {
            this.limits = limits;
            return this;
        }

        /**
         * Sets the value of {@link CloudRunV2ServiceTemplateContainersResources#getStartupCpuBoost}
         * @param startupCpuBoost Determines whether CPU should be boosted on startup of a new container instance above the requested CPU threshold, this can help reduce cold-start latency.
         *                        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/cloud_run_v2_service#startup_cpu_boost CloudRunV2Service#startup_cpu_boost}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder startupCpuBoost(java.lang.Boolean startupCpuBoost) {
            this.startupCpuBoost = startupCpuBoost;
            return this;
        }

        /**
         * Sets the value of {@link CloudRunV2ServiceTemplateContainersResources#getStartupCpuBoost}
         * @param startupCpuBoost Determines whether CPU should be boosted on startup of a new container instance above the requested CPU threshold, this can help reduce cold-start latency.
         *                        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/cloud_run_v2_service#startup_cpu_boost CloudRunV2Service#startup_cpu_boost}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder startupCpuBoost(com.hashicorp.cdktf.IResolvable startupCpuBoost) {
            this.startupCpuBoost = startupCpuBoost;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CloudRunV2ServiceTemplateContainersResources}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CloudRunV2ServiceTemplateContainersResources build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CloudRunV2ServiceTemplateContainersResources}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CloudRunV2ServiceTemplateContainersResources {
        private final java.lang.Object cpuIdle;
        private final java.util.Map<java.lang.String, java.lang.String> limits;
        private final java.lang.Object startupCpuBoost;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.cpuIdle = software.amazon.jsii.Kernel.get(this, "cpuIdle", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.limits = software.amazon.jsii.Kernel.get(this, "limits", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.startupCpuBoost = software.amazon.jsii.Kernel.get(this, "startupCpuBoost", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.cpuIdle = builder.cpuIdle;
            this.limits = builder.limits;
            this.startupCpuBoost = builder.startupCpuBoost;
        }

        @Override
        public final java.lang.Object getCpuIdle() {
            return this.cpuIdle;
        }

        @Override
        public final java.util.Map<java.lang.String, java.lang.String> getLimits() {
            return this.limits;
        }

        @Override
        public final java.lang.Object getStartupCpuBoost() {
            return this.startupCpuBoost;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getCpuIdle() != null) {
                data.set("cpuIdle", om.valueToTree(this.getCpuIdle()));
            }
            if (this.getLimits() != null) {
                data.set("limits", om.valueToTree(this.getLimits()));
            }
            if (this.getStartupCpuBoost() != null) {
                data.set("startupCpuBoost", om.valueToTree(this.getStartupCpuBoost()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-google.cloudRunV2Service.CloudRunV2ServiceTemplateContainersResources"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CloudRunV2ServiceTemplateContainersResources.Jsii$Proxy that = (CloudRunV2ServiceTemplateContainersResources.Jsii$Proxy) o;

            if (this.cpuIdle != null ? !this.cpuIdle.equals(that.cpuIdle) : that.cpuIdle != null) return false;
            if (this.limits != null ? !this.limits.equals(that.limits) : that.limits != null) return false;
            return this.startupCpuBoost != null ? this.startupCpuBoost.equals(that.startupCpuBoost) : that.startupCpuBoost == null;
        }

        @Override
        public final int hashCode() {
            int result = this.cpuIdle != null ? this.cpuIdle.hashCode() : 0;
            result = 31 * result + (this.limits != null ? this.limits.hashCode() : 0);
            result = 31 * result + (this.startupCpuBoost != null ? this.startupCpuBoost.hashCode() : 0);
            return result;
        }
    }
}
